@@ -11,8 +11,9 @@ Within .dialects, each dialect is free to depend on other dialects as
 required. Any dependent dialects will be loaded as needed.
 """
 
+from collections.abc import Iterator
 from importlib import import_module
-from typing import Iterator, NamedTuple
+from typing import NamedTuple
 
 # Eventually it would be a good to dynamically discover dialects
 # from any module beginning with "dialect_" within this folder.
@@ -30,6 +31,7 @@ _dialect_lookup = {
     "exasol": ("dialect_exasol", "exasol_dialect"),
     "greenplum": ("dialect_greenplum", "greenplum_dialect"),
     "hive": ("dialect_hive", "hive_dialect"),
+    "impala": ("dialect_impala", "impala_dialect"),
     "materialize": ("dialect_materialize", "materialize_dialect"),
     "mariadb": ("dialect_mariadb", "mariadb_dialect"),
     "mysql": ("dialect_mysql", "mysql_dialect"),
@@ -40,6 +42,7 @@ _dialect_lookup = {
     "soql": ("dialect_soql", "soql_dialect"),
     "sparksql": ("dialect_sparksql", "sparksql_dialect"),
     "sqlite": ("dialect_sqlite", "sqlite_dialect"),
+    "starrocks": ("dialect_starrocks", "starrocks_dialect"),
     "teradata": ("dialect_teradata", "teradata_dialect"),
     "trino": ("dialect_trino", "trino_dialect"),
     "tsql": ("dialect_tsql", "tsql_dialect"),
