@@ -6,6 +6,7 @@ See https://trino.io/docs/current/language.html
 from sqlfluff.core.dialects import load_raw_dialect
 from sqlfluff.core.parser import (
     AnyNumberOf,
+    AnySetOf,
     Anything,
     BaseSegment,
     Bracketed,
@@ -18,6 +19,7 @@ from sqlfluff.core.parser import (
     Matchable,
     Nothing,
     OneOf,
+    OptionallyBracketed,
     Ref,
     RegexLexer,
     Sequence,
@@ -273,6 +275,10 @@ trino_dialect.replace(
         Ref("ExpressionSegment"),
     ),
     TemporaryTransientGrammar=Nothing(),
+    PrimaryKeyGrammar=Nothing(),
+    ForeignKeyGrammar=Nothing(),
+    UniqueKeyGrammar=Nothing(),
+    TemporaryGrammar=Nothing(),
 )
 
 
@@ -458,16 +464,35 @@ class SetOperatorSegment(BaseSegment):
 
 
 class StatementSegment(ansi.StatementSegment):
-    """Overriding StatementSegment to allow for additional segment parsing."""
+    """A generic segment, to any of its child subsegments."""
 
-    match_grammar = ansi.StatementSegment.match_grammar.copy(
-        insert=[
-            Ref("AnalyzeStatementSegment"),
-            Ref("CommentOnStatementSegment"),
-        ],
-        remove=[
-            Ref("TransactionStatementSegment"),
-        ],
+    type = "statement"
+    match_grammar: Matchable = OneOf(
+        Ref("AlterTableStatementSegment"),
+        Ref("AnalyzeStatementSegment"),
+        Ref("CommentOnStatementSegment"),
+        Ref("CreateFunctionStatementSegment"),
+        Ref("CreateRoleStatementSegment"),
+        Ref("CreateSchemaStatementSegment"),
+        Ref("CreateTableStatementSegment"),
+        Ref("CreateViewStatementSegment"),
+        Ref("DeleteStatementSegment"),
+        Ref("DescribeStatementSegment"),
+        Ref("DropFunctionStatementSegment"),
+        Ref("DropRoleStatementSegment"),
+        Ref("DropSchemaStatementSegment"),
+        Ref("DropTableStatementSegment"),
+        Ref("DropViewStatementSegment"),
+        Ref("ExplainStatementSegment"),
+        Ref("InsertStatementSegment"),
+        Ref("MergeStatementSegment"),
+        Ref("SelectableGrammar"),
+        Ref("SetSchemaStatementSegment"),
+        Ref("TransactionStatementSegment"),
+        Ref("UpdateStatementSegment"),
+        Ref("UseStatementSegment"),
+        Ref("SetSessionStatementSegment"),
+        terminators=[Ref("DelimiterGrammar")],
     )
 
 
@@ -661,3 +686,162 @@ class LambdaExpressionSegment(BaseSegment):
         Ref("LambdaArrowSegment"),
         Ref("ExpressionSegment"),
     )
+
+
+class CreateTableStatementSegment(ansi.CreateTableStatementSegment):
+    """A `CREATE TABLE` statement."""
+
+    type = "create_table_statement"
+    match_grammar: Matchable = Sequence(
+        "CREATE",
+        Ref("OrReplaceGrammar", optional=True),
+        "TABLE",
+        Ref("IfNotExistsGrammar", optional=True),
+        Ref("TableReferenceSegment"),
+        # Columns and comment syntax:
+        Bracketed(
+            Delimited(
+                Ref("ColumnReferenceSegment"),
+                Ref("ColumnDefinitionSegment"),
+                Sequence(
+                    "LIKE",
+                    Ref("TableReferenceSegment"),
+                    Sequence(
+                        OneOf("INCLUDING", "EXCLUDING"),
+                        "PROPERTIES",
+                        optional=True,
+                    ),
+                ),
+            ),
+            optional=True,
+        ),
+        Ref("CommentClauseSegment", optional=True),
+        Sequence(
+            "WITH",
+            Bracketed(
+                Delimited(
+                    Ref("ParameterNameSegment"),
+                    Ref("EqualsSegment"),
+                    Ref("ExpressionSegment"),
+                ),
+            ),
+            optional=True,
+        ),
+        # Create AS syntax:
+        Sequence(
+            "AS",
+            OptionallyBracketed(Ref("SelectableGrammar")),
+            optional=True,
+        ),
+        # Create like syntax
+        Sequence("WITH", Ref.keyword("NO", optional=True), "DATA", optional=True),
+    )
+
+
+class ColumnDefinitionSegment(ansi.ColumnDefinitionSegment):
+    """A column definition, e.g. for CREATE TABLE or ALTER TABLE."""
+
+    type = "column_definition"
+    match_grammar: Matchable = Sequence(
+        Ref("SingleIdentifierGrammar"),  # Column name
+        Ref("DatatypeSegment"),  # Column type
+        Bracketed(Anything(), optional=True),  # For types like VARCHAR(100)
+        AnySetOf(
+            Ref("CommentClauseSegment"),
+            Sequence(
+                "WITH",
+                Bracketed(
+                    Delimited(
+                        Ref("ParameterNameSegment"),
+                        Ref("EqualsSegment"),
+                        Ref("ExpressionSegment"),
+                    ),
+                ),
+            ),
+        ),
+    )
+
+
+class TransactionStatementSegment(ansi.TransactionStatementSegment):
+    """A `COMMIT`, `ROLLBACK` or `TRANSACTION` statement.
+
+    https://trino.io/docs/current/sql/commit.html
+    https://trino.io/docs/current/sql/rollback.html
+    https://trino.io/docs/current/sql/start-transaction.html
+    """
+
+    type = "transaction_statement"
+    match_grammar: Matchable = OneOf(
+        Sequence(
+            "COMMIT",
+            Ref.keyword("WORK", optional=True),
+        ),
+        Sequence(
+            "ROLLBACK",
+            Ref.keyword("WORK", optional=True),
+        ),
+        Sequence(
+            "START",
+            "TRANSACTION",
+            Delimited(
+                Sequence(
+                    "ISOLATION",
+                    "LEVEL",
+                    OneOf(
+                        Sequence("READ", "UNCOMMITTED"),
+                        Sequence("READ", "COMMITTED"),
+                        Sequence("REPEATABLE", "READ"),
+                        "SERIALIZABLE",
+                    ),
+                ),
+                Sequence(
+                    "READ",
+                    OneOf("ONLY", "WRITE"),
+                ),
+                optional=True,
+            ),
+        ),
+    )
+
+
+class InsertStatementSegment(ansi.InsertStatementSegment):
+    """An `INSERT` statement.
+
+    https://trino.io/docs/current/sql/insert.html
+    """
+
+    type = "insert_statement"
+    match_grammar: Matchable = Sequence(
+        "INSERT",
+        "INTO",
+        Ref("TableReferenceSegment"),
+        OneOf(
+            Ref("SelectableGrammar"),
+            Sequence(
+                Ref("BracketedColumnReferenceListGrammar"),
+                Ref("SelectableGrammar"),
+            ),
+            Ref("DefaultValuesGrammar"),
+        ),
+    )
+
+
+class SetSessionStatementSegment(BaseSegment):
+    """A `SET SESSION` statement.
+
+    https://trino.io/docs/current/sql/set-session.html
+    """
+
+    type = "set_session_statement"
+    match_grammar: Matchable = Sequence(
+        "SET",
+        "SESSION",
+        Sequence(
+            Ref("ParameterNameSegment"),
+            Ref("DotSegment"),
+            optional=True,
+        ),
+        Ref("ParameterNameSegment"),
+        Ref("EqualsSegment"),
+        Ref("ExpressionSegment"),
+    )
