@@ -234,6 +234,7 @@ RESERVED_KEYWORDS = [
     "WHEN",
     "WHERE",
     "WHILE",
+    "WINDOW",
     "WITH",
     "WRITETEXT",
 ]
@@ -279,6 +280,7 @@ UNRESERVED_KEYWORDS = [
     "BEFORE",  # *future*
     "BERNOULLI",
     "BINARY",
+    "BLOCK",
     "BLOCKERS",
     "BREAK",
     "CACHE",
@@ -413,6 +415,8 @@ UNRESERVED_KEYWORDS = [
     "IO",
     "ISOLATION",
     "JSON",
+    "JSON_ARRAY",
+    "JSON_OBJECT",
     "KEEP",
     "KEEPDEFAULTS",
     "KEEPFIXED",
@@ -505,9 +509,11 @@ UNRESERVED_KEYWORDS = [
     "PERCENTILE_DISC",
     "PERIOD",
     "PERSISTED",
+    "POLICY",
     "POPULATION",
     "PRECEDING",
     "PRECISION",  # listed as reserved but functionally unreserved
+    "PREDICATE",
     "PRIOR",
     "PROFILE",
     "PROPERTY",
@@ -580,6 +586,7 @@ UNRESERVED_KEYWORDS = [
     "SCOPED",
     "SEARCH",
     "SECRET",
+    "SECURITY",
     "SECURITYAUDIT",  # listed as reserved but functionally unreserved
     "SELF",
     "SEQUENCE_NUMBER_COLUMN_NAME",
@@ -605,6 +612,7 @@ UNRESERVED_KEYWORDS = [
     "SPATIAL_WINDOW_MAX_CELLS",
     "SPLIT",
     "START",
+    "STATE",
     "STATISTICAL_SEMANTICS",
     "STATISTICS_INCREMENTAL",
     "STATISTICS_NORECOMPUTE",
